@@ -1,7 +1,7 @@
 package Git::CPAN::Patch;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Patch CPAN modules using Git
-$Git::CPAN::Patch::VERSION = '2.2.1';
+$Git::CPAN::Patch::VERSION = '2.3.0';
 use 5.10.1;
 
 use strict;
@@ -25,13 +25,13 @@ option man => (
     isa => 'Bool',
     default => 0,
     lazy => 1,
-    trigger => sub { 
+    trigger => sub {
         require Pod::Usage;
         my $name = $_[0]->meta->name . '.pm';
         $name =~ s#::#/#g;
 
         exit Pod::Usage::pod2usage(
-            -verbose => 2, 
+            -verbose => 2,
             -input => $INC{$name}
         );
     },
@@ -93,7 +93,7 @@ Git::CPAN::Patch - Patch CPAN modules using Git
 
 =head1 VERSION
 
-version 2.2.1
+version 2.3.0
 
 =head1 SYNOPSIS
 
@@ -126,6 +126,11 @@ in a local git repository and, once gleeful
 hacking has been perpetrated, sending back
 patches to its maintainer.
 
+NOTE: This module is supported in Linux, BSD, and the like. This 
+module is B<not> supported in Microsoft Windows (Cygwin, Strawberry Perl). 
+See L<CPAN Testers Matrix|http://matrix.cpantesters.org/?dist=Git-CPAN-Patch>
+for currently supported operating systems.
+
 =head1 GIT-CPAN COMMANDS
 
 =over
