@@ -1,12 +1,11 @@
 package Git::CPAN::Patch::Command::Import;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: Import a module into a git repository
-$Git::CPAN::Patch::Command::Import::VERSION = '2.2.1';
+$Git::CPAN::Patch::Command::Import::VERSION = '2.3.0';
 use 5.10.0;
 
 use strict;
 use warnings;
-
 use File::Temp qw/ tempdir /;
 use Method::Signatures::Simple;
 use Git::Repository;
@@ -72,6 +71,15 @@ has metacpan => (
     },
 );
 
+option author_name => (
+    is => 'ro',
+    documentation => "explicitly set the author's name",
+);
+
+option author_email => (
+    is => 'ro',
+    documentation => "explicitly set the author's email",
+);
 
 method get_releases_from_url($url) {
     require LWP::Simple;
@@ -81,11 +89,12 @@ method get_releases_from_url($url) {
 
     say "copying '$url' to '$destination'";
 
-    LWP::Simple::mirror( $url => $destination ) or die;
+    LWP::Simple::mirror( $url => $destination ) 
+        or die "Failed to mirror $url\n";
 
-    return Git::CPAN::Patch::Release->new( 
+    return Git::CPAN::Patch::Release->new(
         metacpan => $self->metacpan,
-        tarball => $destination 
+        tarball => $destination
     );
 }
 
@@ -114,9 +123,9 @@ sub looks_like_git {
 }
 
 method get_releases_from_cpan($dist_or_module) {
-    
+
     # is it a module belonging to a distribution?
-    my $dist = eval{ $self->metacpan->module($dist_or_module)->data->{distribution} 
+    my $dist = eval{ $self->metacpan->module($dist_or_module)->data->{distribution}
     } || $dist_or_module;
 
      if ( $dist eq 'perl' ) {
@@ -128,7 +137,7 @@ method get_releases_from_cpan($dist_or_module) {
         my $repo = $latest_release->data->{metadata}{resources}{repository};
         if ( looks_like_git($repo) ) {
             say "Git repository found: ", $repo->{url};
-            $self->clone_git_repo(Git::CPAN::Patch::Release->new( 
+            $self->clone_git_repo(Git::CPAN::Patch::Release->new(
                 metacpan => $self->metacpan,
                 dist_name => $dist,
                 meta_info => $latest_release,
@@ -215,9 +224,9 @@ method import_release($release) {
         # TODO authors and author_date
 
         # create the commit object
-        $ENV{GIT_AUTHOR_NAME}  = $release->author_name  if $release->author_name;
-        $ENV{GIT_AUTHOR_EMAIL} = $release->author_email if $release->author_email;
-        $ENV{GIT_AUTHOR_DATE}  = $release->date         if $release->date;
+        $ENV{GIT_AUTHOR_NAME}  = $self->author_name  || $release->author_name  || $ENV{GIT_AUTHOR_NAME};
+        $ENV{GIT_AUTHOR_EMAIL} = $self->author_email || $release->author_email || $ENV{GIT_AUTHOR_EMAIL};
+        $ENV{GIT_AUTHOR_DATE}  = $release->date if $release->date;
 
         my @parents = grep { $_ } $self->last_commit, @{ $self->parent };
 
@@ -277,7 +286,7 @@ Git::CPAN::Patch::Command::Import - Import a module into a git repository
 
 =head1 VERSION
 
-version 2.2.1
+version 2.3.0
 
 =head1 SYNOPSIS
 
@@ -333,6 +342,16 @@ the imported CPAN package:
 
 More than one '--parent' can be specified.
 
+=item --author_name
+
+Forces the author name to the given value, instead of trying to resolve it from
+the release metadata.
+
+=item --author_email
+
+Forces the author email to the given value, instead of trying to resolve it from
+the release metadata.
+
 =back
 
 =head1 AUTHORS
