@@ -1,12 +1,11 @@
 package Git::CPAN::Patch::Command::Sources;
 our $AUTHORITY = 'cpan:YANICK';
 #ABSTRACT: lists sources for the module
-$Git::CPAN::Patch::Command::Sources::VERSION = '2.2.1';
+$Git::CPAN::Patch::Command::Sources::VERSION = '2.3.0';
 use 5.10.0;
 
 use strict;
 use warnings;
-
 use Method::Signatures::Simple;
 use List::Pairwise qw/ mapp /;
 
@@ -64,7 +63,7 @@ has release_meta => (
 
         my $thingy = $self->thingy;
 
-        eval { $mcpan->release( 
+        eval { $mcpan->release(
                 distribution => $mcpan->module($thingy)->{distribution}
         ) }
         || eval { $mcpan->release( distribution => $thingy ) }
@@ -98,9 +97,9 @@ method run {
     if ( $self->backpan ) {
         say "backpan:";
         my $dist = $self->backpan_index->dist($self->thingy)
-            or die "could not find distribution on BackPAN";
+            or die "could not find distribution on BackPAN\n";
 
-        say "  - ", $BackPAN_URL . "/" . $_->prefix 
+        say "  - ", $BackPAN_URL . "/" . $_->prefix
             for $dist->releases->search( undef, { order_by => "date" } )->all;
     }
 }
@@ -120,7 +119,7 @@ Git::CPAN::Patch::Command::Sources - lists sources for the module
 
 =head1 VERSION
 
-version 2.2.1
+version 2.3.0
 
 =head1 SYNOPSIS
 
